<?php
/**
 * Di Restaurant Actions Filter. This file is responsible mostly actions and filters.
 *
 * @package Di Restaurant
 */

/**
 * Class Di_Restaurant_Engine.
 */

class Di_Restaurant_Actions_Filter {

	/**
	 * Instance object.
	 *
	 * @var instance
	 */
	public static $instance;

	/**
	 * Get_instance method.
	 *
	 * @return instance instance of the class.
	 */
	public static function get_instance() {
		if ( empty( self::$instance ) ) {
			self::$instance = new self;
		}
		return self::$instance;
	}

	/**
	 * [__construct description]
	 */
	public function __construct() {
		add_action( 'di_restaurant_the_head', [ $this, 'the_head' ] );
		add_filter( 'get_calendar', [ $this, 'calendar_css_class' ] );
		add_filter( 'widget_tag_cloud_args', [ $this, 'tag_cloud_fontsize_fix' ] );
		add_filter( 'di_restaurant_footer_cprt_right', [ $this, 'footer_cprt_right_contents' ] );
		add_action( 'di_restaurant_header_img_file', [ $this, 'header_img_file_clbk' ] );
		add_action( 'wp_enqueue_scripts', [ $this, 'inline_css' ] );
		add_filter( 'body_class', [ $this, 'di_body_class' ] );
		add_action( 'customize_register', [ $this, 'customize_pr_handle' ], 9999999 );

		if( ! is_admin() ) {
			add_filter( 'excerpt_length', [ $this, 'excerpt_length' ] );
			add_filter( 'excerpt_more', [ $this, 'excerpt_more' ] );
		}

		if( class_exists( 'WooCommerce' ) ) {
			add_filter( 'woocommerce_product_tag_cloud_widget_args', [ $this, 'woo_tag_cloud_fontsize_fix' ] );
		}
	}

	public function the_head() {
		?>
		<meta charset="<?php bloginfo( 'charset' ); ?>" />
		<meta http-equiv="X-UA-Compatible" content="IE=edge" />
		<meta name="viewport" content="width=device-width, initial-scale=1" />
		<link rel="profile" href="http://gmpg.org/xfn/11" />

		<?php if ( is_singular() && pings_open( get_queried_object() ) ) { ?>
		<link rel="pingback" href="<?php bloginfo( 'pingback_url' ); ?>">
		<?php } ?>
		
		<?php
	}

	public function calendar_css_class( $html ) {
		return str_replace( 'id="wp-calendar"', 'id="wp-calendar" class="table table-bordered"', $html );
	}

	public function tag_cloud_fontsize_fix( $args ) {
		$args['largest']  = 14;
		$args['smallest'] = 14;
		$args['unit']     = 'px';
		return $args;
	}

	public function inline_css() {
		
		$custom_css = "";

		// blog_list_grid
		if( get_theme_mod( 'blog_list_grid', 'list' ) == 'msry2c' ) {
			$custom_css .= "
				@media (min-width: 768px) {
					.dimasonrybox {
						width: 48%;
						margin-right: 2% !important;
					}
				}
				";
		}

		if( get_theme_mod( 'blog_list_grid', 'list' ) == 'msry3c' ) {
			$custom_css .= "
				@media (min-width: 768px) {
					.dimasonrybox {
						width: 31%;
						margin-right: 2% !important;
					}
				}
				";
		}

		// For load icon
		if( get_theme_mod( 'loading_icon_img' ) ) {
			$icon_link =  esc_url( get_theme_mod( 'loading_icon_img' ) );
		} else {
			$icon_link =  esc_url( get_template_directory_uri() . '/assets/images/Preloader_2.gif' );
		}

		$custom_css .= "
		.load-icon {
			position: fixed;
			left: 0px;
			top: 0px;
			width: 100%;
			height: 100%;
			z-index: 9999999;
			background: url( '" . $icon_link . "' ) center no-repeat #fff;
		}
		";

		// For disable / enable sticky menu small device.
		if( get_theme_mod( 'stickymenu_setting_lrg', '1' ) == 1 ) { // sticky is enabled for large device
			$custom_css .= "
			@media (min-width: 768px) {
				#navbarouter {
					position: fixed;
					top: 0;
				}

				.sticky_menu_top {
					position: fixed;
					top: 0;
				}

				.header-img-otr {
					min-height: 50px;
				}
			}
			";
		} else { // Sticky disabled for large device so remove margin-top: -50px from first elemetor section.
			$custom_css .= "
			.page-template-template-full-width-page-builder.elementor-page .elementor-section-wrap section.elementor-element:first-child {
				margin-top: 0;
			}
			";
		}

		if( get_theme_mod( 'stickymenu_setting_smal', '0' ) == 1 ) { // Sticky enabled for small device
			$custom_css .= "
			@media (max-width: 767px) {
				#navbarouter {
					position: fixed;
					top: 0;
				}

				.sticky_menu_top {
					position: fixed;
					top: 0;
				}

				.header-img-otr {
					min-height: 50px;
				}
			}
			";
		} else { // Sticky disabled for small device so remove margin-top: -50px from first elemetor section.
			$custom_css .= "
			.page-template-template-full-width-page-builder.elementor-page .elementor-section-wrap section.elementor-element:first-child {
				margin-top: 0;
			}
			";
		}



		wp_add_inline_style( 'di-restaurant-style-core', $custom_css );
	}

	public function di_body_class( $classes ) {
		if( get_theme_mod( 'loading_icon', '0' ) == 1 ) {
			return array_merge( $classes, array( 'overflowhide' ) );
		}
		return array_merge( $classes, array( '' ) );
	}

	public function customize_pr_handle( $wp_customize ) {
		$wp_customize->get_setting( 'custom_logo' )->transport 	= 'refresh';
		
	}

	public function excerpt_length() {
		return absint( get_theme_mod( 'excerpt_length', '40' ) );
	}

	public function excerpt_more( $more ) {
		global $post;
		return '... <div class="readmore-section"><a href="' . esc_url( get_permalink( $post->ID ) ) . '"><input type="submit" name="submit" value="' . __( 'Continue reading', 'di-restaurant' ) . '&#8230;" class="readmore-btn" ></a></div>';

	}

	public function footer_cprt_right_contents() {
		
		printf(
			/* translators: 1: p tag open, 2: p tag close, 3: fa icon and a tag open, 4: fa icon & a tag close */
			esc_html__( '%1$sWordPress %3$s Di Restaurant%4$s Theme%2$s', 'di-restaurant' ), 
			'<p>',
			'</p>',
			'<span class="footer_span fa fa-thumbs-o-up"><a href="#">',
			'</a></span>'
		);

	}

	public function header_img_file_clbk() {
		?>
		<div class="header-img-otr">

			<?php
			// return if disabled using metabox (disabled on individual page || post)
			if( is_home() ) {
				$di_post_id = get_option( 'page_for_posts' );
			} else {
				$di_post_id = get_the_ID();
			}

			if( $di_post_id ) {
				if( get_post_meta( $di_post_id, '_di_restaurant_hide_hdrimg', true ) == '1' ) {
					?>
					</div> <!-- header-img-otr END -->
					<?php
					return;
				}
			}

			if( has_header_image() ) { ?>
			<div class="container-fluid header-img">
				<?php the_custom_header_markup(); ?>
			</div>
			<?php
			}
			?>
			
		</div> <!-- header-img-otr END -->
		<?php
	}







	public function woo_tag_cloud_fontsize_fix( $args ) {
		$args['largest']  = 14;
		$args['smallest'] = 14;
		$args['unit']     = 'px';
		return $args;
	}

}
Di_Restaurant_Actions_Filter::get_instance();
